import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ContainerAnalysisOccurrenceConfig extends cdktf.TerraformMetaArguments {
    /**
     * The analysis note associated with this occurrence, in the form of projects/[PROJECT]/notes/[NOTE_ID].
     *
     * This field can be used as a
     * filter in list requests.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#note_name ContainerAnalysisOccurrence#note_name}
     */
    readonly noteName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#project ContainerAnalysisOccurrence#project}.
     */
    readonly project?: string;
    /**
     * A description of actions that can be taken to remedy the note.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#remediation ContainerAnalysisOccurrence#remediation}
     */
    readonly remediation?: string;
    /**
     * Required. Immutable. A URI that represents the resource for which the occurrence applies. For example, https://gcr.io/project/image@sha256:123abc for a Docker image.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#resource_uri ContainerAnalysisOccurrence#resource_uri}
     */
    readonly resourceUri: string;
    /**
     * attestation block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#attestation ContainerAnalysisOccurrence#attestation}
     */
    readonly attestation: ContainerAnalysisOccurrenceAttestation;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#timeouts ContainerAnalysisOccurrence#timeouts}
     */
    readonly timeouts?: ContainerAnalysisOccurrenceTimeouts;
}
export interface ContainerAnalysisOccurrenceAttestationSignatures {
    /**
     * The identifier for the public key that verifies this signature.
     *
     * MUST be an RFC3986 conformant
     * URI. * When possible, the key id should be an
     * immutable reference, such as a cryptographic digest.
     * Examples of valid values:
     *
     * OpenPGP V4 public key fingerprint. See https://www.iana.org/assignments/uri-schemes/prov/openpgp4fpr
     * for more details on this scheme.
     *  'openpgp4fpr:74FAF3B861BDA0870C7B6DEF607E48D2A663AEEA'
     * RFC6920 digest-named SubjectPublicKeyInfo (digest of the DER serialization):
     *  "ni:///sha-256;cD9o9Cq6LG3jD0iKXqEi_vdjJGecm_iXkbqVoScViaU"
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#public_key_id ContainerAnalysisOccurrence#public_key_id}
     */
    readonly publicKeyId: string;
    /**
     * The content of the signature, an opaque bytestring.
     *
     * The payload that this signature verifies MUST be
     * unambiguously provided with the Signature during
     * verification. A wrapper message might provide the
     * payload explicitly. Alternatively, a message might
     * have a canonical serialization that can always be
     * unambiguously computed to derive the payload.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#signature ContainerAnalysisOccurrence#signature}
     */
    readonly signature?: string;
}
export interface ContainerAnalysisOccurrenceAttestation {
    /**
     * The serialized payload that is verified by one or more signatures. A base64-encoded string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#serialized_payload ContainerAnalysisOccurrence#serialized_payload}
     */
    readonly serializedPayload: string;
    /**
     * signatures block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#signatures ContainerAnalysisOccurrence#signatures}
     */
    readonly signatures: ContainerAnalysisOccurrenceAttestationSignatures[];
}
export declare class ContainerAnalysisOccurrenceAttestationOutputReference extends cdktf.ComplexObject {
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _serializedPayload?;
    get serializedPayload(): string;
    set serializedPayload(value: string);
    get serializedPayloadInput(): string | undefined;
    private _signatures?;
    get signatures(): ContainerAnalysisOccurrenceAttestationSignatures[];
    set signatures(value: ContainerAnalysisOccurrenceAttestationSignatures[]);
    get signaturesInput(): ContainerAnalysisOccurrenceAttestationSignatures[] | undefined;
}
export interface ContainerAnalysisOccurrenceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#create ContainerAnalysisOccurrence#create}.
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#delete ContainerAnalysisOccurrence#delete}.
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html#update ContainerAnalysisOccurrence#update}.
     */
    readonly update?: string;
}
export declare class ContainerAnalysisOccurrenceTimeoutsOutputReference extends cdktf.ComplexObject {
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _create?;
    get create(): string | undefined;
    set create(value: string | undefined);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string | undefined;
    set delete(value: string | undefined);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string | undefined;
    set update(value: string | undefined);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html google_container_analysis_occurrence}.
 */
export declare class ContainerAnalysisOccurrence extends cdktf.TerraformResource {
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/container_analysis_occurrence.html google_container_analysis_occurrence} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     */
    constructor(scope: Construct, id: string, config: ContainerAnalysisOccurrenceConfig);
    get createTime(): string;
    get id(): string;
    get kind(): string;
    get name(): string;
    private _noteName?;
    get noteName(): string;
    set noteName(value: string);
    get noteNameInput(): string | undefined;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _remediation?;
    get remediation(): string | undefined;
    set remediation(value: string | undefined);
    resetRemediation(): void;
    get remediationInput(): string | undefined;
    private _resourceUri?;
    get resourceUri(): string;
    set resourceUri(value: string);
    get resourceUriInput(): string | undefined;
    get updateTime(): string;
    private _attestation?;
    private __attestationOutput;
    get attestation(): ContainerAnalysisOccurrenceAttestationOutputReference;
    putAttestation(value: ContainerAnalysisOccurrenceAttestation): void;
    get attestationInput(): ContainerAnalysisOccurrenceAttestation | undefined;
    private _timeouts?;
    private __timeoutsOutput;
    get timeouts(): ContainerAnalysisOccurrenceTimeoutsOutputReference;
    putTimeouts(value: ContainerAnalysisOccurrenceTimeouts | undefined): void;
    resetTimeouts(): void;
    get timeoutsInput(): ContainerAnalysisOccurrenceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
